require 'pathname'
require 'test_helper'


class Axl::ConfigurationTest < Axl::Test

  describe 'Axl::Configuration' do

    let :path do
      Pathname.new(__FILE__).join('..', '..', 'support', 'bogus.yml')
    end

    let :valid_config do
      {
        'test' => {
          'endpoint' => 'somewhere'
        }
      }
    end

    describe '::load' do

      it 'loads the configuration from the given path for the given env' do
        YAML.expects(:load_file).with(path).returns(valid_config)

        config = Axl::Configuration.load(path, env: 'test')

        config.must_be_instance_of Axl::Configuration
        config.to_h.must_equal valid_config['test']
      end

      it 'throws an error when the configuration file is not found' do
        method = lambda do
          Axl::Configuration.load(path, env: 'test')
        end
        method.must_raise Axl::ConfigurationFileNotFoundError

        error = method.call rescue $!

        error.message.wont_be_nil
      end

    end

    describe '#endpoint' do

      it 'returns the configured endpoint for the env' do
        YAML.stubs(:load_file).returns(valid_config)

        config = Axl::Configuration.load(path, env: 'test')

        config.endpoint.must_equal valid_config['test']['endpoint']
      end

    end

  end

end
